﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using StartToBike.DAL;
using StartToBike.Models;

namespace StartToBike.Controllers
{
    public class RidesController : Controller
    {
        private DatabaseContext db = new DatabaseContext();

        // My rides page
        public ActionResult Index()
        {
            // Get rides of user
            int userID = ((User)Session["user"]).ID;
            var rides = db.Rides.Where(r => r.UserID == userID).Include(r => r.Route).Include(r => r.User);

            // Return view
            return View(rides.ToList());
        }

        // Details page for ride
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Ride ride = db.Rides.Find(id);
            if (ride == null)
            {
                return HttpNotFound();
            }
            return View(ride);
        }

        // New ride page
        public ActionResult Create()
        {
            ViewBag.RouteID = new SelectList(db.Routes, "ID", "Name");
            ViewBag.UserID = new SelectList(db.Users, "ID", "Email");
            return View();
        }

        // New ride page (process data)
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "ID,DateTime,Distance,Time,RouteID,UserID")] Ride ride, int id)
        {
            User owner = (User)Session["user"];
            ride.UserID = owner.ID;
            ride.RouteID = id;
            if (ModelState.IsValid)
            {
                db.Rides.Add(ride);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.RouteID = new SelectList(db.Routes, "ID", "Name", ride.RouteID);
            ViewBag.UserID = new SelectList(db.Users, "ID", "Email", ride.UserID);
            return View(ride);
        }

        // Edit ride page
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Ride ride = db.Rides.Find(id);
            if (ride == null)
            {
                return HttpNotFound();
            }
            ViewBag.RouteID = new SelectList(db.Routes, "ID", "Name", ride.RouteID);
            ViewBag.UserID = new SelectList(db.Users, "ID", "Email", ride.UserID);
            return View(ride);
        }

        // Edit ride page (process data)
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "ID,DateTime,Distance,Time,RouteID,UserID")] Ride editedRide)
        {
            // Update the edited values
            Ride ride = db.Rides.Find(editedRide.ID);
            ride.DateTime = editedRide.DateTime;
            ride.Time = editedRide.Time;

            // Save changes
            if (ModelState.IsValid)
            {
                db.Entry(ride).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            // Return view
            ViewBag.RouteID = new SelectList(db.Routes, "ID", "Name", ride.RouteID);
            ViewBag.UserID = new SelectList(db.Users, "ID", "Email", ride.UserID);
            return View(ride);
        }

        // Delete a ride page
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Ride ride = db.Rides.Find(id);
            if (ride == null)
            {
                return HttpNotFound();
            }
            return View(ride);
        }

        // Delete a ride page (process data)
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            Ride ride = db.Rides.Find(id);
            db.Rides.Remove(ride);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
