﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using StartToBike.DAL;
using StartToBike.Models;

namespace StartToBike.Controllers
{
    public class RoutesController : Controller
    {
        private DatabaseContext db = new DatabaseContext();

        // Routes page
        public ActionResult Index()
        {
            var routes = db.Routes.Include(r => r.Owner);
            return View(routes.ToList());
        }

        // Page for a route
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Route route = db.Routes.Find(id);
            if (route == null)
            {
                return HttpNotFound();
            }
            return View(route);
        }

        // New route page
        public ActionResult Create()
        {
            return View();
        }

        // New route page (process data)
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "ID,UserID,Name,Description,Region,RouteLink,Intensity")] Route route)
        {
            // Get the user
            User user = (User)Session["user"];
            user = db.Users.Find(user.ID);

            // Set user in route
            route.Owner = user;

            // Save to database
            if (ModelState.IsValid)
            {
                db.Routes.Add(route);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(route);
        }

        // Edit route page
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Route route = db.Routes.Find(id);
            if (route == null)
            {
                return HttpNotFound();
            }

            return View(route);
        }

        // Edit route page (process data)
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "ID,UserID,Name,Description,Region,RouteLink,Intensity")] Route route)
        {
            if (ModelState.IsValid)
            {
                db.Entry(route).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Details", new { id = route.ID });
            }

            return View(route);
        }

        // New review page
        public ActionResult WriteReview(int routeID)
        {
            int userID = ((User)Session["user"]).ID;

            List<Review> reviewsOfUser = db.Reviews.Where(r => r.RouteID == routeID && r.UserID == userID).ToList();

            if (reviewsOfUser.Count == 0)
            {
                return View();
            }

            return RedirectToAction("EditReview", new { routeID = routeID });
        }

        // New review page (process data)
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult WriteReview([Bind(Include = "ID,UserID,Rating,ReviewText,RouteID")] Review review)
        {
            // Get the user
            User user = (User)Session["user"];
            user = db.Users.Find(user.ID);

            // Set user in review
            review.Owner = user;

            // Save to database
            if (ModelState.IsValid)
            {
                db.Reviews.Add(review);
                db.SaveChanges();
                return RedirectToAction("Details", new { id = review.RouteID });
            }

            return View(review);
        }

        // Edit review page
        public ActionResult EditReview(int routeID)
        {
            if (routeID == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            int userID = ((User)Session["user"]).ID;
            Review review = db.Reviews.Where(r => r.RouteID == routeID && r.UserID == userID).FirstOrDefault();
            if (review == null)
            {
                return HttpNotFound();
            }

            return View(review);
        }

        // Edit review page (process data)
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult EditReview([Bind(Include = "ID,UserID,Rating,ReviewText,RouteID")] Review review)
        {
            if (ModelState.IsValid)
            {
                db.Entry(review).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Details", new { id = review.RouteID });
            }

            return View(review);
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
