﻿using StartToBike.DAL;
using StartToBike.Models;
using StartToBike.ViewModels;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace StartToBike.Controllers
{
    public class TrainingsController : Controller
    {
        private DatabaseContext db = new DatabaseContext();

        // Homepage for training
        public ActionResult Index()
        {
            return View();
        }

        // Questionnare
        public ActionResult Questionnare()
        {
            return View();
        }

        // Questionnare (process data)
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Questionnare([Bind(Include = "Experience,Length,Weight,Age")] TrainingQuestionsViewModel trainingQuestions)
        {
            // Calculate BMI
            float lengthInMeters = trainingQuestions.Length / 100;
            float bmi = trainingQuestions.Weight / (lengthInMeters * lengthInMeters);

            // Get score for experience
            int score = 0;
            score += trainingQuestions.Experience;

            // Get score for bmi (= weight and length)
            if (bmi >= 18.5 && bmi <= 25)
            {
                score += 2;
            } else
            {
                score += 1;
            }

            // Get score for age
            if (trainingQuestions.Age < 16)
            {
                score += 1;
            } else if (trainingQuestions.Age >= 16 && trainingQuestions.Age < 40)
            {
                score += 2;
            } else if (trainingQuestions.Age >= 40 && trainingQuestions.Age < 55)
            {
                score += 1;
            }

            // Determine recommended intensity
            if (score < 4)
            {
                ViewBag.Intensity = "kleiner dan 2";
            } else if (score < 6)
            {
                ViewBag.Intensity = "tussen de 2 en 4";
            } else
            {
                ViewBag.Intensity = "van 4 of hoger";
            }
            

            return View("QuestionnareResult");
        }

        // Questionnare result page
        public ActionResult QuestionnareResult()
        {
            return View();
        }

        public ActionResult RecommendationExperience()
        {
            // Find rides of user
            int userID = ((User)Session["user"]).ID;
            List<Ride> rides = db.Rides.Where(r => r.UserID == userID).OrderByDescending(r => r.DateTime).ToList();

            // Calculate recommended intensity (= average of previous 10 rides + 0.5)
            double totalIntensity = 0;
            double recommendedIntensity = 0;
            if (rides.Count < 10)
            {
                foreach (Ride ride in rides)
                {
                    totalIntensity += ride.Route.Intensity;
                }
                recommendedIntensity = (totalIntensity / (double)rides.Count) + 0.5;
            } else
            {
                for (int i = 0; i < 10; i++)
                {
                    totalIntensity += rides[i].Route.Intensity;
                }
                recommendedIntensity = totalIntensity / 10 + 0.5;
            }

            // Round intensity
            recommendedIntensity = Math.Round(recommendedIntensity * 10) / 10;
            if (recommendedIntensity > 5)
            {
                recommendedIntensity = 5;
            }

            // Return view with intensity
            ViewBag.Intensity = recommendedIntensity;

            return View();
        }
    }
}