﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Security.Cryptography;
using System.Web;
using System.Web.Mvc;
using StartToBike.DAL;
using StartToBike.Models;
using StartToBike.ViewModels;

namespace StartToBike.Controllers
{
    public class UsersController : Controller
    {
        private DatabaseContext db = new DatabaseContext();

        public ActionResult Register()
        {
            return View();
        }

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Register([Bind(Include = "User,PasswordConfirm")] RegisterViewModel registerViewModel)
        {
            // Check if passwords match
            if (registerViewModel.User.Password != registerViewModel.PasswordConfirm)
            {
                return View();
            }

            // Check if email already exists
            int occurencesOfEmail = db.Users.Where(u => u.Email == registerViewModel.User.Email).ToList().Count;
            if (occurencesOfEmail > 0)
            {
                return View();
            }

            // Hash and salt password
            registerViewModel.User.HashAndSalt();
            
            // Check ModelState
            if (!ModelState.IsValid)
            {
                return View();
            }

            // Register the user
            db.Users.Add(registerViewModel.User);
            db.SaveChanges();

            // Find the registered user
            User user = db.Users.Where(u => u.Email == registerViewModel.User.Email).FirstOrDefault();
            Session["user"] = user;

            // Return view
            return RedirectToAction("Menu", "Home");
        }

        public ActionResult Login()
        {
            return View();
        }

        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Login([Bind(Include = "ID,Email,Password")] User user)
        {

            // Get user currently stored in database
            User userFromDb = db.Users.Where(u => u.Email == user.Email).FirstOrDefault();

            // Check login
            if (user.Login(userFromDb) == true)
            {
                Session["user"] = userFromDb;
                return RedirectToAction("Menu", "Home");
            }

            // Incorrect credentials
            return View();
        }

        public ActionResult Logout()
        {
            Session.Clear();
            return RedirectToAction("Index", "Home");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
