﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Linq;
using System.Web;

namespace StartToBike.Models
{
    /// <summary>
    /// Review for a route.
    /// </summary>
    public class Review
    {
        /// <summary>
        /// Identifier.
        /// </summary>
        public int ID { get; set; }

        /// <summary>
        /// UserID of the writer of the review
        /// </summary>
        [ForeignKey("Owner")]
        public int? UserID { get; set; }

        /// <summary>
        /// Rating for the route on a scale from 1 to 5.
        /// </summary>
        [Display(Name = "Beoordeling op schaal van 1 tot 5")]
        public int Rating { get; set; }

        /// <summary>
        /// Text for a review.
        /// </summary>
        [Display(Name = "Beschrijf uw review")]
        public string ReviewText { get; set; }

        /// <summary>
        /// The ID of the route where the review is for.
        /// </summary>
        public int RouteID { get; set; }

        /// <summary>
        /// The route where the review is for.
        /// </summary>
        public virtual Route Route { get; set; }

        /// <summary>
        /// The writer of the review.
        /// </summary>
        public virtual User Owner { get; set; }
    }
}