﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Web;

namespace StartToBike.Models
{
    /// <summary>
    /// A ride a user has ridden. Can be with or without a route.
    /// </summary>
    public class Ride
    {
        /// <summary>
        /// Identifier.
        /// </summary>
        public int ID { get; set; }

        /// <summary>
        /// The date and time when the ride was ridden.
        /// </summary>
        [Display(Name = "Datum en tijd")]
        public DateTime DateTime { get; set; }

        /// <summary>
        /// Distance of the ride.
        /// </summary>
        [Display(Name = "Afstand")]
        public int Distance { get; set; }

        /// <summary>
        /// Time to ride the route in minutes.
        /// </summary>
        [Display(Name = "Duur in minuten")]
        public int Time { get; set; }

        /// <summary>
        /// ID of the ridden route.
        /// </summary>
        public int? RouteID { get; set; }

        /// <summary>
        /// The ridden route.
        /// </summary>
        public virtual Route Route { get; set; }

        /// <summary>
        /// The ID of the user who has ridden the ride.
        /// </summary>
        public int UserID { get; set; }

        /// <summary>
        /// The user who has ridden the ride.
        /// </summary>
        public virtual User User { get; set; }
    }
}