﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Linq;
using System.Web;

namespace StartToBike.Models
{
    /// <summary>
    /// A route which can be ridden.
    /// </summary>
    public class Route
    {
        /// <summary>
        /// Identifier.
        /// </summary>
        public int ID { get; set; }

        /// <summary>
        /// The ID of the owner.
        /// </summary>
        [ForeignKey("Owner")]
        public int UserID { get; set; }

        /// <summary>
        /// The owner of the route.
        /// </summary>
        public virtual User Owner { get; set; }

        /// <summary>
        /// The name of the route.
        /// </summary>
        [Display(Name = "Naam")]
        public string Name { get; set; }

        /// <summary>
        /// The description of the route.
        /// </summary>
        [Display(Name = "Beschrijving")]
        public string Description { get; set; }

        /// <summary>
        /// The region where the route is.
        /// </summary>
        [Display(Name = "Regio")]
        public string Region { get; set; }

        /// <summary>
        /// The Google Maps link of the route.
        /// </summary>
        [Display(Name = "Link")]
        public string RouteLink { get; set; }

        /// <summary>
        /// Intensity of the route (1-5).
        /// </summary>
        [Display(Name = "Intensiteit op schaal van 1 tot 5")]
        public int Intensity { get; set; }

        /// <summary>
        /// Reviews for the route.
        /// </summary>
        public virtual ICollection<Review> Reviews { get; set; }

        /// <summary>
        /// Average rating of all reviews
        /// </summary>
        public int AverageRating
        {
            get
            {
                double totalRating = 0;
                if (this.Reviews == null)
                {
                    return 0;
                } else if (this.Reviews.Count == 0) {
                    return 0;
                }
                foreach (Review review in this.Reviews) 
                {
                    totalRating += review.Rating;
                }

                double average = totalRating / this.Reviews.Count;
                return (int)Math.Round(average);
            }
        }

        /// <summary>
        /// Rides where this route has been ridden.
        /// </summary>
        public virtual ICollection<Ride> Rides { get; set; }

        /// <summary>
        /// Tours where this route will be ridden.
        /// </summary>
        public virtual ICollection<Tour> Tours { get; set; }
    }
}