﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Linq;
using System.Security.Cryptography;
using System.Web;

namespace StartToBike.Models
{
    /// <summary>
    /// A user.
    /// </summary>
    public class User
    {
        /// <summary>
        /// Identifier.
        /// </summary>
        public int ID { get; set; }

        /// <summary>
        /// The email of the user.
        /// </summary>
        [Display(Name = "E-mailadres")]
        public string Email { get; set; }

        /// <summary>
        /// The hashed password of the user.
        /// </summary>
        [Display(Name = "Wachtwoord")]
        public string Password { get; set; }

        /// <summary>
        /// The rides the user has ridden.
        /// </summary>
        public virtual ICollection<Ride> Rides { get; set; }

        /// <summary>
        /// Routes the user has created.
        /// </summary>
        public virtual ICollection<Route> OwnerOfRoutes { get; set; }

        /// <summary>
        /// Tours where user is owner of.
        /// </summary>
        [InverseProperty("Owner")]
        public virtual ICollection<Tour> OwnerOfTours { get; set; }

        /// <summary>
        /// Tours where the user participates in
        /// </summary>
        [InverseProperty("Participants")]
        public virtual ICollection<Tour> ParticipatesInTours { get; set; }

        /// <summary>
        /// Hashing and salting the password
        /// </summary>
        /// <returns>True on success</returns>
        public bool HashAndSalt()
        {
            byte[] salt;

            new RNGCryptoServiceProvider().GetBytes(salt = new byte[16]);

            var pbkdf2 = new Rfc2898DeriveBytes(this.Password, salt, 10000);

            byte[] hash = pbkdf2.GetBytes(20);

            byte[] hashBytes = new byte[36];

            Array.Copy(salt, 0, hashBytes, 0, 16);
            Array.Copy(hash, 0, hashBytes, 16, 20);

            string savedPasswordHash = Convert.ToBase64String(hashBytes);
            this.Password = savedPasswordHash;

            return true;
        }

        /// <summary>
        /// Checks if password is correct
        /// </summary>
        /// <param name="userFromDb">User currently stored in database</param>
        /// <returns>True if password is correct, otherwise false</returns>
        public bool Login(User userFromDb)
        {
            string savedPasswordHash = userFromDb.Password;
            byte[] hashBytes = Convert.FromBase64String(savedPasswordHash);

            byte[] salt = new byte[16];
            Array.Copy(hashBytes, 0, salt, 0, 16);
            var pbkdf2 = new Rfc2898DeriveBytes(this.Password, salt, 10000);

            byte[] hash = pbkdf2.GetBytes(20);

            bool ok = true;
            for (int i = 0; i < 20; i++)
            {
                if (hashBytes[i + 16] != hash[i])
                    ok = false;
            }

            return ok;
        }
    }
}